.. psqlgml documentation master file, created by
   sphinx-quickstart on Fri Aug 20 21:49:24 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

psqlgml's documentation!
========================

.. contents::::
   :depth: 2
   :caption: Contents:



Indices and tables
==================
